@@ -38,13 +38,18 @@ the terms of any one of the MPL, the GPL or the LGPL.
 */
 
 #include "spatialite/geopackage.h"
-#include "config.h"
 #include "geopackage_internal.h"
 
+#if defined(_WIN32) && !defined(__MINGW32__)
+#include "config-msvc.h"
+#else
+#include "config.h"
+#endif
+
 #ifdef ENABLE_GEOPACKAGE
 GEOPACKAGE_PRIVATE void
-fnct_gpkgAddTileTriggers (sqlite3_context * context, int argc
-			  __attribute__ ((unused)), sqlite3_value ** argv)
+fnct_gpkgAddTileTriggers (sqlite3_context * context, int argc,
+			  sqlite3_value ** argv)
 {
 /* SQL function:
 / gpkgAddTileTriggers(table)
@@ -61,18 +66,16 @@ fnct_gpkgAddTileTriggers (sqlite3_context * context, int argc
     int i = 0;
     /* Note: the code below relies on there being twelve (or less) varargs, all of which are the table name */
     const char *trigger_stmts[] = {
-	"CREATE TRIGGER \"%s_zoom_insert\"\n"
-	    "BEFORE INSERT ON \"%s\"\n"
+	"CREATE TRIGGER \"%s_zoom_insert\"\n" "BEFORE INSERT ON \"%s\"\n"
 	    "FOR EACH ROW BEGIN\n"
 	    "SELECT RAISE(ABORT, 'insert on table ''%s'' violates constraint: zoom_level not specified for table in gpkg_tile_matrix')\n"
-	    "WHERE NOT (NEW.zoom_level IN (SELECT zoom_level FROM gpkg_tile_matrix WHERE table_name = \"%s\"));\n"
+	    "WHERE NOT (NEW.zoom_level IN (SELECT zoom_level FROM gpkg_tile_matrix WHERE table_name = %Q));\n"
 	    "END",
 
 	"CREATE TRIGGER \"%s_zoom_update\"\n"
-	    "BEFORE UPDATE OF zoom_level ON \"%s\"\n"
-	    "FOR EACH ROW BEGIN\n"
+	    "BEFORE UPDATE OF zoom_level ON \"%s\"\n" "FOR EACH ROW BEGIN\n"
 	    "SELECT RAISE(ABORT, 'update on table ''%s'' violates constraint: zoom_level not specified for table in gpkg_tile_matrix')\n"
-	    "WHERE NOT (NEW.zoom_level IN (SELECT zoom_level FROM gpkg_tile_matrix WHERE table_name = \"%s\"));\n"
+	    "WHERE NOT (NEW.zoom_level IN (SELECT zoom_level FROM gpkg_tile_matrix WHERE table_name = %Q));\n"
 	    "END",
 
 	"CREATE TRIGGER \"%s_tile_column_insert\"\n"
@@ -81,7 +84,7 @@ fnct_gpkgAddTileTriggers (sqlite3_context * context, int argc
 	    "SELECT RAISE(ABORT, 'insert on table ''%s'' violates constraint: tile_column cannot be < 0')\n"
 	    "WHERE (NEW.tile_column < 0) ;\n"
 	    "SELECT RAISE(ABORT, 'insert on table ''%s'' violates constraint: tile_column must be < matrix_width specified for table and zoom level in gpkg_tile_matrix')\n"
-	    "WHERE NOT (NEW.tile_column < (SELECT matrix_width FROM gpkg_tile_matrix WHERE table_name = '%s' AND zoom_level = NEW.zoom_level));\n"
+	    "WHERE NOT (NEW.tile_column < (SELECT matrix_width FROM gpkg_tile_matrix WHERE table_name = %Q AND zoom_level = NEW.zoom_level));\n"
 	    "END",
 
 	"CREATE TRIGGER \"%s_tile_column_update\"\n"
@@ -90,7 +93,7 @@ fnct_gpkgAddTileTriggers (sqlite3_context * context, int argc
 	    "SELECT RAISE(ABORT, 'update on table ''%s'' violates constraint: tile_column cannot be < 0')\n"
 	    "WHERE (NEW.tile_column < 0) ;\n"
 	    "SELECT RAISE(ABORT, 'update on table ''%s'' violates constraint: tile_column must be < matrix_width specified for table and zoom level in gpkg_tile_matrix')\n"
-	    "WHERE NOT (NEW.tile_column < (SELECT matrix_width FROM gpkg_tile_matrix WHERE table_name = '%s' AND zoom_level = NEW.zoom_level));\n"
+	    "WHERE NOT (NEW.tile_column < (SELECT matrix_width FROM gpkg_tile_matrix WHERE table_name = %Q AND zoom_level = NEW.zoom_level));\n"
 	    "END",
 
 	"CREATE TRIGGER \"%s_tile_row_insert\"\n"
@@ -99,7 +102,7 @@ fnct_gpkgAddTileTriggers (sqlite3_context * context, int argc
 	    "SELECT RAISE(ABORT, 'insert on table ''%s'' violates constraint: tile_row cannot be < 0')\n"
 	    "WHERE (NEW.tile_row < 0) ;\n"
 	    "SELECT RAISE(ABORT, 'insert on table ''%s'' violates constraint: tile_row must be < matrix_height specified for table and zoom level in gpkg_tile_matrix')\n"
-	    "WHERE NOT (NEW.tile_row < (SELECT matrix_height FROM gpkg_tile_matrix WHERE table_name = '%s' AND zoom_level = NEW.zoom_level));\n"
+	    "WHERE NOT (NEW.tile_row < (SELECT matrix_height FROM gpkg_tile_matrix WHERE table_name = %Q AND zoom_level = NEW.zoom_level));\n"
 	    "END",
 
 	"CREATE TRIGGER \"%s_tile_row_update\"\n"
@@ -108,12 +111,15 @@ fnct_gpkgAddTileTriggers (sqlite3_context * context, int argc
 	    "SELECT RAISE(ABORT, 'update on table ''%s'' violates constraint: tile_row cannot be < 0')\n"
 	    "WHERE (NEW.tile_row < 0) ;\n"
 	    "SELECT RAISE(ABORT, 'update on table ''%s'' violates constraint: tile_row must be < matrix_height specified for table and zoom level in gpkg_tile_matrix')\n"
-	    "WHERE NOT (NEW.tile_row < (SELECT matrix_height FROM gpkg_tile_matrix WHERE table_name = '%s' AND zoom_level = NEW.zoom_level));\n"
+	    "WHERE NOT (NEW.tile_row < (SELECT matrix_height FROM gpkg_tile_matrix WHERE table_name = %Q AND zoom_level = NEW.zoom_level));\n"
 	    "END",
 
 	NULL
     };
 
+    if (argc == 0)
+	argc = 0;		/* suppressing stupid compiler warnings */
+
     if (sqlite3_value_type (argv[0]) != SQLITE_TEXT)
       {
 	  sqlite3_result_error (context,
