@@ -2,7 +2,7 @@
 
  virtualdbf.c -- SQLite3 extension [VIRTUAL TABLE accessing DBF]
 
- version 5.0, 2020 August 1
+ version 5.1.0, 2023 August 4
 
  Author: Sandro Furieri a.furieri@lqt.it
 
@@ -24,7 +24,7 @@ The Original Code is the SpatiaLite library
 
 The Initial Developer of the Original Code is Alessandro Furieri
  
-Portions created by the Initial Developer are Copyright (C) 2008-2021
+Portions created by the Initial Developer are Copyright (C) 2008-2023
 the Initial Developer. All Rights Reserved.
 
 Contributor(s):
@@ -369,7 +369,21 @@ vdbf_best_index (sqlite3_vtab * pVTab, sqlite3_index_info * pIndex)
     *str = '\0';
     for (i = 0; i < pIndex->nConstraint; i++)
       {
-	  if (pIndex->aConstraint[i].usable)
+	  if (pIndex->aConstraint[i].usable &&
+	      /* 2022-02-23 - patch for SQLite 3.38 proposed by Even Rouault */
+	      (pIndex->aConstraint[i].op == SQLITE_INDEX_CONSTRAINT_EQ ||
+	       pIndex->aConstraint[i].op == SQLITE_INDEX_CONSTRAINT_GT ||
+	       pIndex->aConstraint[i].op == SQLITE_INDEX_CONSTRAINT_LE ||
+	       pIndex->aConstraint[i].op == SQLITE_INDEX_CONSTRAINT_LT ||
+	       pIndex->aConstraint[i].op == SQLITE_INDEX_CONSTRAINT_GE ||
+	       pIndex->aConstraint[i].op == SQLITE_INDEX_CONSTRAINT_NE ||
+	       pIndex->aConstraint[i].op == SQLITE_INDEX_CONSTRAINT_ISNOTNULL ||
+	       pIndex->aConstraint[i].op == SQLITE_INDEX_CONSTRAINT_ISNULL
+#ifdef HAVE_DECL_SQLITE_INDEX_CONSTRAINT_LIKE
+	       || pIndex->aConstraint[i].op == SQLITE_INDEX_CONSTRAINT_LIKE
+#endif
+	      ))
+	      /* 2022-02-23 - end patch Even Rouault */
 	    {
 		iArg++;
 		pIndex->aConstraintUsage[i].argvIndex = iArg;
