@@ -2,7 +2,7 @@
 
  virtualxpath.c -- SQLite3 extension [VIRTUAL XPath handler]
 
- version 5.0, 2020 August 1
+ version 5.1.0, 2023 August 4
 
  Author: Sandro Furieri a.furieri@lqt.it
 
@@ -24,7 +24,7 @@ The Original Code is the SpatiaLite library
 
 The Initial Developer of the Original Code is Alessandro Furieri
  
-Portions created by the Initial Developer are Copyright (C) 2008-2020
+Portions created by the Initial Developer are Copyright (C) 2008-2024
 the Initial Developer. All Rights Reserved.
 
 Contributor(s):
@@ -71,7 +71,7 @@ the terms of any one of the MPL, the GPL or the LGPL.
 
 #include <spatialite/sqlite.h>
 
-#include <spatialite/spatialite.h>
+#include <spatialite/spatialite_ext.h>
 #include <spatialite/debug.h>
 #include <spatialite/gaiaaux.h>
 #include <spatialite/gaiageo.h>
