@@ -122,7 +122,7 @@ main (int argc UNUSED, char *argv[]UNUSED)
 
     ret =
 	sqlite3_exec (db_handle,
-		      "SELECT gpkgCreateTilesTable(\"test1_matrix_tiles\", 4326, -180.0, -90.0, 180.0, 90.0)",
+		      "SELECT gpkgCreateTilesTable('test1_matrix_tiles', 4326, -180.0, -90.0, 180.0, 90.0)",
 		      NULL, NULL, &err_msg);
     if (ret != SQLITE_OK)
       {
@@ -159,7 +159,7 @@ main (int argc UNUSED, char *argv[]UNUSED)
     /* create matrix level 0 and 4 */
     ret =
 	sqlite3_exec (db_handle,
-		      "SELECT gpkgCreateTilesZoomLevel(\"test1_matrix_tiles\", 0, 360, 180)",
+		      "SELECT gpkgCreateTilesZoomLevel('test1_matrix_tiles', 0, 360, 180)",
 		      NULL, NULL, &err_msg);
     if (ret != SQLITE_OK)
       {
@@ -171,7 +171,7 @@ main (int argc UNUSED, char *argv[]UNUSED)
       }
     ret =
 	sqlite3_exec (db_handle,
-		      "SELECT gpkgCreateTilesZoomLevel(\"test1_matrix_tiles\", 4, 360, 180)",
+		      "SELECT gpkgCreateTilesZoomLevel('test1_matrix_tiles', 4, 360, 180)",
 		      NULL, NULL, &err_msg);
     if (ret != SQLITE_OK)
       {
