@@ -557,6 +557,10 @@ run_all_testcases (struct db_conn *conn, int load_extension, int legacy)
     int result = 0;
     const char *security_level;
     int tiny_point = is_tiny_point_enabled (conn->cache);
+#ifndef OMIT_GEOS		/* only if GEOS is supported */
+	char geos_version[32];
+	sprintf(geos_version, "%04d.%04d.%04d",  GEOS_VERSION_MAJOR, GEOS_VERSION_MINOR, GEOS_VERSION_PATCH);
+#endif
 
     result = run_subdir_test ("sql_stmt_tests", conn, load_extension, 0);
     if (result != 0)
@@ -699,11 +703,20 @@ run_all_testcases (struct db_conn *conn, int load_extension, int legacy)
     if (!legacy)
       {
 	  int is_720_or_later = 0;
+	  int is_910_or_later = 0;
 	  if (PROJ_VERSION_MAJOR > 7)
 	      is_720_or_later = 1;
 	  else if (PROJ_VERSION_MAJOR == 7 && PROJ_VERSION_MINOR >= 2)
 	      is_720_or_later = 1;
-	  if (is_720_or_later)
+	  if (PROJ_VERSION_MAJOR > 9)
+	      is_910_or_later = 1;
+	  else if (PROJ_VERSION_MAJOR == 9 && PROJ_VERSION_MINOR >= 1)
+	      is_910_or_later = 1;
+	  if (is_910_or_later)
+	      result =
+		  run_subdir_test ("sql_stmt_proj910_tests", conn,
+				   load_extension, 0);
+	  else if (is_720_or_later)
 	      result =
 		  run_subdir_test ("sql_stmt_proj720_tests", conn,
 				   load_extension, 0);
@@ -730,7 +743,7 @@ run_all_testcases (struct db_conn *conn, int load_extension, int legacy)
 #endif /* end EPSG conditional */
 
 #ifndef OMIT_GEOS		/* only if GEOS is supported */
-    if (strcmp (GEOSversion (), "3.3") < 0)
+    if (strcmp (geos_version, "0003.0003") < 0)
       {
 	  /* 
 	     skipping GEOS tests if some obsolete version is found 
@@ -756,7 +769,43 @@ run_all_testcases (struct db_conn *conn, int load_extension, int legacy)
       {
 	  return result;
       }
-    if (strcmp (GEOSversion (), "3.8") >= 0)
+    if (strcmp (geos_version, "0003.0012") >= 0)
+      {
+	  /* GEOS 3.12.0 changed historical beheviour for few tests */
+	  result =
+	      run_subdir_test ("sql_stmt_geos_3120", conn, load_extension, 0);
+      }
+    else
+      {
+	  /* older versions supporting historical beheviour for some tests */
+	  result =
+	      run_subdir_test ("sql_stmt_geos_non3120", conn, load_extension, 0);
+      }
+    if (strcmp (geos_version, "0003.0011") >= 0)
+      {
+	  /* GEOS 3.11.0 changed historical beheviour for few tests */
+	  result =
+	      run_subdir_test ("sql_stmt_geos_3110", conn, load_extension, 0);
+      }
+    else
+      {
+	  /* older versions supporting historical beheviour for some tests */
+	  result =
+	      run_subdir_test ("sql_stmt_geos_non3110", conn, load_extension, 0);
+      }
+    if (strcmp (geos_version, "0003.0010") >= 0)
+      {
+	  /* GEOS 3.10.0 changed historical beheviour for few tests */
+	  result =
+	      run_subdir_test ("sql_stmt_geos_3100", conn, load_extension, 0);
+      }
+    else
+      {
+	  /* older versions supporting historical beheviour for some tests */
+	  result =
+	      run_subdir_test ("sql_stmt_geos_non3100", conn, load_extension, 0);
+      }
+    if (strcmp (geos_version, "0003.0008") >= 0)
       {
 	  /* GEOS 3.8.0 changed historical beheviour for some tests */
 	  result =
@@ -770,7 +819,13 @@ run_all_testcases (struct db_conn *conn, int load_extension, int legacy)
       }
     if (result != 0)
 	return result;
-    if (strcmp (GEOSversion (), "3.9") >= 0)
+    if (strcmp (geos_version, "0003.0009.0001") >= 0)
+      {
+	  /* GEOS 3.9.1 changed historical beheviour for some tests */
+	  result =
+	      run_subdir_test ("sql_stmt_geos_391", conn, load_extension, 0);
+      }
+    else if (strcmp (geos_version, "0003.0009") >= 0)
       {
 	  /* GEOS 3.9.0 changed historical beheviour for some tests */
 	  result =
@@ -789,7 +844,7 @@ run_all_testcases (struct db_conn *conn, int load_extension, int legacy)
 #endif /* end GEOS conditional */
 
 #ifdef GEOS_ADVANCED		/* only if GEOS_ADVANCED is supported */
-    if (strcmp (GEOSversion (), "3.4") < 0)
+    if (strcmp (geos_version, "0003.0004") < 0)
       {
 	  /* 
 	     skipping GEOS tests if some obsolete version is found 
@@ -826,7 +881,7 @@ run_all_testcases (struct db_conn *conn, int load_extension, int legacy)
       {
 	  return result;
       }
-    if (strcmp (GEOSversion (), "3.9") >= 0)
+    if (strcmp (geos_version, "0003.0009") >= 0)
       {
 	  /* GEOS 3.9.0 changed historical beheviour for some tests */
 	  result =
@@ -861,6 +916,28 @@ run_all_testcases (struct db_conn *conn, int load_extension, int legacy)
 
 #endif /* end GEOS_370 conditional */
 
+#ifdef GEOS_3100			/* only if GEOS_3100 is supported */
+
+    result =
+	run_subdir_test ("sql_stmt_geos3100_tests", conn, load_extension, 0);
+    if (result != 0)
+      {
+	  return result;
+      }
+
+#endif /* end GEOS_3100 conditional */
+
+#ifdef GEOS_3110			/* only if GEOS_3110 is supported */
+
+    result =
+	run_subdir_test ("sql_stmt_geos3110_tests", conn, load_extension, 0);
+    if (result != 0)
+      {
+	  return result;
+      }
+
+#endif /* end GEOS_3110 conditional */
+
 #ifdef ENABLE_RTTOPO		/* only if RTTOPO is supported */
     if (legacy)
       {
@@ -875,7 +952,7 @@ run_all_testcases (struct db_conn *conn, int load_extension, int legacy)
       {
 	  return result;
       }
-    if (strcmp (GEOSversion (), "3.9") >= 0)
+    if (strcmp (geos_version, "0003.0009") >= 0)
       {
 	  /* GEOS 3.9.0 changed historical beheviour for some tests */
 	  result =
